#!/bin/sh -e

. shell-error

verbose=

rpath=
basedir=
bindir=
libdir=
idldir=
includedir=

TEMP=`getopt -n $PROG -o v,h -l develdir:,bindir:,libdir:,idldir:,includedir:,rpath:,verbose,help -- "$@"` ||
	show_usage
eval set -- "$TEMP"
while :; do
	case "$1" in
		--develdir) shift
			basedir="$(readlink -ev "$1")"
			;;
		--bindir) shift
			bindir="$(readlink -ev "$1")"
			;;
		--libdir) shift
			libdir="$(readlink -ev "$1")"
			;;
		--idldir) shift
			idldir="$(readlink -ev "$1")"
			;;
		--includedir) shift
			includedir="$(readlink -ev "$1")"
			;;
		--rpath) shift
			rpath="$1"
			;;
		-v|--verbose) verbose=-v
			;;
		-h|--help) show_help
			;;
		--) shift; break
			;;
		*) fatal "Unrecognized option: $1"
			;;
	esac
	shift
done

[ -d "$basedir" ] ||
	fatal "develdir required"

[ -d "$bindir" ] ||
	fatal "bindir required"

[ -d "$libdir" ] ||
	fatal "libdir required"

[ -d "$includedir" ] ||
	fatal "includedir required"

set -x

# Fixup bin
while read link target; do
	[ -z "${target%%/*}" ] ||
		continue

	t="$(relative "$target" "$link")"
	ln $verbose -nsf -- "$t" "$link"
done <<-EOF
`find -P "$bindir" "$basedir" -type l -printf '%p\t%l\n'`
EOF

### Fixup lib
if [ -n "$rpath" ]; then
	fake_rpath="/$(printf '%s' "$rpath" |tr '[:print:]' '_')"
	while read f; do
		file "$f" | grep -qs ELF ||
			continue

		if chrpath -l "$f" |fgrep -qs "RPATH=$fake_rpath"; then
			chrpath -r "$rpath" "$f"
		fi
	done <<-EOF
	`find "$libdir" "$basedir/sdk/lib" -type f`
	EOF
fi

### Fixup SDK
for d in bin lib; do
    while read fn; do
		name="${fn##*/}"
		[ -e "$basedir/$name" ] ||
			continue

		cmp -s "$basedir/$name" "$fn" ||
			continue

		target="$(relative "$basedir/$name" "$fn")" ||
			continue

		rm $verbose -f -- "$fn" ||:
		ln $verbose -nsf -- "$target" "$fn"
	done <<-EOF
	`find "$basedir/sdk/$d" '!' -type d`
	EOF
done
